%define gitver git272eaf7
%define realver 1.13

Name:	   barnyard2
Version:	%{realver}
Release:	7.%{?gitver}%{?dist}
Summary:	Barnyard2 is an open source interpreter for Snort unified2 binary output files.

BuildRoot:	%(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

Group:	    Applications/Internet
License:	GPLv2
### git url https://github.com/firnsy/barnyard2
URL:	    http://www.securixlive.com/barnyard2
Source0:	%{name}-%{realver}.tar.xz
Source1:	barnyard2.service
Source2:	barnyard2.sysconfig
Source3:	barnyard2-tmpfiles.conf

BuildRequires:  autoconf automake libtool
BuildRequires:  libpcap-devel
BuildRequires:  mysql-devel
Requires:       mysql-server mysql-libs

%if 0%{?fedora} >= 17
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
%else
Requires(post): /sbin/chkconfig
Requires(preun):	/sbin/chkconfig /sbin/service
%endif

%description
Barnyard2 is an open source interpreter for Snort unified2 binary output files.
Its primary use is allowing Snort to write to disk in an efficient manner and
leaving the task of parsing binary data into various formats to a separate
process that will not cause Snort to miss network traffic.

%prep
%setup -q -n %{name}-%{realver}
./autogen.sh

%build
export LIBS="-lpthread"
%configure \
%ifarch x86_64
	--enable-64bit-gcc \
%endif
	--enable-shared \
	--disable-static \
	--enable-ipv6 \
	--enable-gre \
	--enable-mpls \
	--enable-mysql-ssl-support \
	--with-mysql=%{_prefix} \
	--with-mysql-libraries=%{_libdir}/mysql \
	--with-mysql-includes=%{_includedir}/mysql

make %{?_smp_mflags}

%install
#make install DESTDIR=%{buildroot}

install -d -m0755 $RPM_BUILD_ROOT%{_sbindir}
install -d -m0755 $RPM_BUILD_ROOT%{_sysconfdir}/barnyard2
install -d -m0755 $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig
install -d -m0770 $RPM_BUILD_ROOT%{_localstatedir}/run/barnyard2
install -d -m0755 $RPM_BUILD_ROOT%{_localstatedir}/log/barnyard2
install -d -m0755 $RPM_BUILD_ROOT%{_localstatedir}/log/barnyard2/archive
touch $RPM_BUILD_ROOT%{_localstatedir}/log/barnyard2/barnyard2.waldo
%if 0%{?fedora} >= 17
	install -D -m0644 %{SOURCE1} $RPM_BUILD_ROOT%{_unitdir}/barnyard2.service
	install -D -m0644 %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/barnyard2
	install -D -m0644 %{SOURCE3} $RPM_BUILD_ROOT%{_sysconfdir}/tmpfiles.d/barnyard2.conf
%else
	sed -i -e 's,/etc/snort/barnyard.conf,%{_sysconfdir}/barnyard2/barnyard2.conf,g;' rpm/barnyard2.config
	sed -i -e 's,\$SNORTDIR/\$INT,\$SNORTDIR,g;' \
		-e 's,\$SNORTDIR/\${INT},\$SNORTDIR,g;' \
		-e 's,-L ,-l ,g;' \
		-e 's,Snort Output Processor,Snort/Suricata Output Processor,g;' \
		src/barnyard2
	install -d -m0755 $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d
	install -D -m0644 rpm/barnyard2.config $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/barnyard2
	install -D -m0755 rpm/barnyard2 $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d/barnyard2
%endif
install -D -m0755 src/barnyard2 $RPM_BUILD_ROOT%{_sbindir}/barnyard2
install -D -m0600 etc/barnyard2.conf $RPM_BUILD_ROOT%{_sysconfdir}/barnyard2/barnyard2.conf

%post
rpm -q suricata > /dev/null 2>&1
RET=$?
if [ $RET = 0 ]
then
	sed -i -e 's,/etc/snort,/etc/suricata,g;' %{_sysconfdir}/barnyard2/barnyard2.conf
	%if 0%{?rhel} || 0%{?fedora} < 17
		sed -i -e 's,snort,suricata,g;' \
		-e 's,suricata.conf,suricata.yaml,g;' \
		%if 0%{?rhel} || 0%{?fedora} < 17
			%{_sysconfdir}/rc.d/init.d/barnyard2
			sed -i -e 's,/var/log/snort,/var/log/barnyard2,g;' \
			-e 's,snort_unified.log,unified2.alert,g;' \
			%{_sysconfdir}/sysconfig/barnyard2
		%endif
	%endif
fi
%if 0%{?fedora} >= 17
	%systemd_post barnyard2.service
%else
	/sbin/chkconfig --add barnyard2 || :
%endif

%preun
%if 0%{?fedora} >= 17
	%systemd_preun barnyard2.service
%else
if [ $1 -eq 0 ] ; then
	/sbin/service barnyard2 stop > /dev/null 2>&1 || :
	/sbin/chkconfig --del barnyard2
fi
%endif

%postun
%if 0%{?fedora} >= 17
	%systemd_postun_with_restart barnyard2.service
%else
if [ $1 -ge 1 ]; then
	/sbin/service barnyard2 restart > /dev/null 2>&1 || :
fi
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%check
make check

%files
%doc COPYING LICENSE README RELEASE.NOTES doc/INSTALL doc/README* schemas/create_* schemas/SCHEMA_ACCESS
%{_sbindir}/barnyard2
%if 0%{?fedora} >= 17
%{_unitdir}/barnyard2.service
%{_sysconfdir}/tmpfiles.d/barnyard2.conf
%else
%{_sysconfdir}/rc.d/init.d/barnyard2
%endif
%config(noreplace) %{_sysconfdir}/sysconfig/barnyard2
%config(noreplace) %{_sysconfdir}/barnyard2/barnyard2.conf
%dir %attr(0770,root,root) %{_localstatedir}/run/barnyard2
%attr(0600,root,root) %{_localstatedir}/log/barnyard2/barnyard2.waldo
%dir %{_localstatedir}/log/barnyard2/archive

%changelog
* Tue Jan  7 2014 momo-i <webmaster@momo-i.org> - 1.13-7
- Update info

* Wed Dec 25 2013 momo-i <webmaster@momo-i.org> - 1.13-6
- Drop prelude support

* Mon Jul  1 2013 momo-i <webmaster@momo-i.org> 1.13-5
-Update git 272eaf7

* Fri May 10 2013 momo-i <webmaster@momo-i.org> 1.13-4
- Update 1.13
- Update git f1c5e2d

* Fri Mar  1 2013 momo-i <webmaster@momo-i.org> 1.12-1
- Update 1.12

* Fri Aug  3 2012 momo-i <webmaster@momo-i.org> 1.11-1
- Initial rpm release.
